@@ -12,15 +12,17 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import logging
 
 from django.utils.translation import ugettext_lazy as _
 from horizon import exceptions
 from horizon import tabs
 
 from tacker_horizon.openstack_dashboard import api
+from tacker_horizon.openstack_dashboard.dashboards.nfv import utils
 from tacker_horizon.openstack_dashboard.dashboards.nfv.vnfmanager import tables
-from tacker_horizon.openstack_dashboard.dashboards.nfv.vnfmanager.tables import VNFManagerItem  # noqa
-from tacker_horizon.openstack_dashboard.dashboards.nfv.vnfmanager.tables import VNFManagerItemList  # noqa
+
+LOG = logging.getLogger(__name__)
 
 
 class VNFManagerTab(tabs.TableTab):
@@ -42,7 +44,7 @@ class VNFManagerTab(tabs.TableTab):
             #    self.request,
             #    search_opts={'marker': marker, 'paginate': True})
             self._has_more = True
-            VNFManagerItemList.clear_list()
+            tables.VNFManagerItemList.clear_list()
             vnfs = api.tacker.vnf_list(self.request)
             for vnf in vnfs:
                 try:
@@ -55,16 +57,17 @@ class VNFManagerTab(tabs.TableTab):
                     vnf_desc_str = ""
 
                 vim = vnf['placement_attr']['vim_name']
-                obj = VNFManagerItem(vnf['name'],
-                                     vnf_desc_str,
-                                     vnf_services_str,
-                                     vim,
-                                     vnf['status'],
-                                     vnf['status'],
-                                     vnf['id'],
-                                     vnf['error_reason'])
-                VNFManagerItemList.add_item(obj)
-            return VNFManagerItemList.VNFLIST_P
+                obj = tables.VNFManagerItem(
+                    vnf['name'],
+                    vnf_desc_str,
+                    vnf_services_str,
+                    vim,
+                    vnf['status'],
+                    vnf['status'],
+                    vnf['id'],
+                    vnf['error_reason'])
+                tables.VNFManagerItemList.add_item(obj)
+            return tables.VNFManagerItemList.VNFLIST_P
         except Exception:
             self._has_more = False
             error_message = _('Unable to get instances')
@@ -88,7 +91,38 @@ class VDUDetailTab(tabs.Tab):
         return {'vnf': self.tab_group.kwargs['vnf']}
 
 
+class VNFEventsTab(tabs.TableTab):
+    name = _("Events Tab")
+    slug = "events_tab"
+    table_classes = (utils.EventsTable,)
+    template_name = ("horizon/common/_detail_table.html")
+    preload = False
+
+    def has_more_data(self, table):
+        return self._has_more
+
+    def get_events_data(self):
+        try:
+            self._has_more = True
+            utils.EventItemList.clear_list()
+            events = api.tacker.events_list(self.request,
+                                            self.tab_group.kwargs['vnf_id'])
+            for event in events:
+                evt_obj = utils.EventItem(
+                    event['id'], event['resource_state'],
+                    event['event_type'],
+                    event['timestamp'],
+                    event['event_details'])
+                utils.EventItemList.add_item(evt_obj)
+            return utils.EventItemList.EVTLIST_P
+        except Exception as e:
+            self._has_more = False
+            error_message = _('Unable to get events %s') % e
+            exceptions.handle(self.request, error_message)
+            return []
+
+
 class VNFDetailsTabs(tabs.TabGroup):
     slug = "VNF_details"
-    tabs = (VDUDetailTab,)
+    tabs = (VDUDetailTab, VNFEventsTab)
     sticky = True
